package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DEREnumerated;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;

public class ObjectDigestInfo extends ASN1Encodable {
   public static final int publicKey = 0;
   public static final int publicKeyCert = 1;
   public static final int otherObjectDigest = 2;
   DEREnumerated digestedObjectType;
   DERObjectIdentifier otherObjectTypeID;
   AlgorithmIdentifier digestAlgorithm;
   DERBitString objectDigest;

   public static ObjectDigestInfo getInstance(Object obj) {
      if (obj != null && !(obj instanceof ObjectDigestInfo)) {
         if (obj instanceof ASN1Sequence) {
            return new ObjectDigestInfo((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (ObjectDigestInfo)obj;
      }
   }

   public static ObjectDigestInfo getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public ObjectDigestInfo(int digestedObjectType, String otherObjectTypeID, AlgorithmIdentifier digestAlgorithm, byte[] objectDigest) {
      DEREnumerated var5;
      var5 = new DEREnumerated.<init>(digestedObjectType);
      this.digestedObjectType = var5;
      if (digestedObjectType == 2) {
         DERObjectIdentifier digestedObjectType1;
         digestedObjectType1 = new DERObjectIdentifier.<init>(otherObjectTypeID);
         this.otherObjectTypeID = digestedObjectType1;
      }

      ObjectDigestInfo var10000 = this;
      this.digestAlgorithm = digestAlgorithm;
      DERBitString var6;
      var6 = new DERBitString.<init>(objectDigest);
      var10000.objectDigest = var6;
   }

   private ObjectDigestInfo(ASN1Sequence seq) {
      if (seq.size() <= 4 && seq.size() >= 3) {
         this.digestedObjectType = DEREnumerated.getInstance(seq.getObjectAt(0));
         byte var2 = 0;
         if (seq.size() == 4) {
            this.otherObjectTypeID = DERObjectIdentifier.getInstance(seq.getObjectAt(1));
            var2 = 1;
         }

         this.digestAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(var2 + 1));
         this.objectDigest = DERBitString.getInstance(seq.getObjectAt(var2 + 2));
      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public DEREnumerated getDigestedObjectType() {
      return this.digestedObjectType;
   }

   public DERObjectIdentifier getOtherObjectTypeID() {
      return this.otherObjectTypeID;
   }

   public AlgorithmIdentifier getDigestAlgorithm() {
      return this.digestAlgorithm;
   }

   public DERBitString getObjectDigest() {
      return this.objectDigest;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.digestedObjectType);
      DERObjectIdentifier var2;
      if ((var2 = this.otherObjectTypeID) != null) {
         var1.add(var2);
      }

      var1.add(this.digestAlgorithm);
      var1.add(this.objectDigest);
      return new DERSequence(var1);
   }
}
